{
package SAP_RFC;

use strict;
use Carp;
use vars qw($VERSION @ISA @EXPORT_OK $AUTOLOAD);

require Exporter;
use DynaLoader;

@ISA = qw(Exporter DynaLoader);
# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.
@EXPORT_OK = qw(
	RFC_BAD
	RFC_BAD_IN
	RFC_ERR
	RFC_ERROR
	RFC_OK
	RFC_RETRY
	RFC_TIMEOUT
	RFC_TO
	SAPRFC_H
);
$VERSION = '0.19';

sub AUTOLOAD {
    # This AUTOLOAD is used to 'autoload' constants from the constant()
    # XS function.  If a constant is not found then control is passed
    # to the AUTOLOAD in AutoLoader.

    my $constname;
    ($constname = $AUTOLOAD) =~ s/.*:://;
    my $val = constant($constname, @_ ? $_[0] : 0);
    if ($! != 0) {
	if ($! =~ /Invalid/) {
	    $AutoLoader::AUTOLOAD = $AUTOLOAD;
	    goto &AutoLoader::AUTOLOAD;
	}
	else {
		croak "Your vendor has not defined SAP_RFC macro $constname";
	}
    }
    eval "sub $AUTOLOAD { $val }";
    goto &$AUTOLOAD;
}

bootstrap SAP_RFC $VERSION; 

# Preloaded methods go here.

sub SAP_RFC::help
{
    my $i = 0;
    my $str = ' ';
    
    for ($i = 0; $i < 1520; $i++)
    {
        $str = $str." ";
    }

    &SAP_RFC::rfc_help($str);

    return ($str);    
}

sub SAP_RFC::version
{
    return(&SAP_RFC::rfc_version());
}

sub SAP_RFC::open
{
 
    my ($sys, $cli, $usr, $pwd, $trc) = @_;
       
    return(&SAP_RFC::rfc_open($sys, $cli, $usr, $pwd, $trc));
}

sub SAP_RFC::close
{
    return(&SAP_RFC::rfc_close());
}

sub SAP_RFC::callrx1
{
     my $mess_out = ' ';
     my $ret_val = -9;
     my $i = 0;
     
     my ($prog, $mess_in) = @_;
     
    for ($i = 0; $i < 250; $i++)
    {
        $mess_out = $mess_out." ";
    }
    
     $ret_val = &SAP_RFC::rfc_callrx1($prog, $mess_in, $mess_out);
     
     return($ret_val, $mess_out);
}

sub SAP_RFC::callrx2
{
     my $mess1_out = ' ';
     my $mess2_out = ' ';
     my $ret_val = -9;
     my $i = 0;

     my ($prog, $mess_in) = @_;
     
    for ($i = 0; $i < 250; $i++)
    {
        $mess1_out = $mess1_out." ";
        $mess2_out = $mess2_out." ";
   }
   
     $ret_val = &SAP_RFC::rfc_callrx2($prog, $mess_in, $mess1_out, $mess2_out);
     
     return($ret_val, $mess1_out, $mess2_out);
}

sub SAP_RFC::callrxx
{
     my $mess_out = ' ';
     my $ret_val = -9;
     my $i = 0;
     
     my ($prog, $mess_in, $str_ex, $str_imp) = @_;
     
    for ($i = 0; $i < 250; $i++)
    {
        $mess_out = $mess_out." ";
    }
    
     $ret_val = &SAP_RFC::rfc_callrxx($prog, $mess_in, $mess_out, $str_ex, $str_imp);
     
     
     return($ret_val, $mess_out);
}

sub SAP_RFC::ping
{
    my $i = 0;
    my $str = ' ';
    my $ret_val = 0;
    
    for ($i = 0; $i < 300; $i++)
    {
        $str = $str." ";
    }

    $ret_val = &SAP_RFC::rfc_rfcping($str);

    return ($ret_val, $str);    
}

sub SAP_RFC::sysinfo
{
    my $i = 0;
    my $istr = ' ';
    my $ret_val = 0;
    my $info = ' ';
    
    for ($i = 0; $i < 300; $i++)
    {
        $istr = $istr." ";
     }
     
    $ret_val = &SAP_RFC::rfc_sysinfo($istr);
    
    $info = join( ':',
        join (';', 'RFC Log Version', substr($istr,0, 3)),
        join (';', 'Character Set (SAP)', substr($istr,3, 4)), 
        join (';', 'Integer Format', substr($istr,7, 3)), 
        join (';', 'Floating Point Format', substr($istr,10, 3)),
        join (';', 'Logical SAP Destination', substr($istr,13, 32)),
        join (';', 'Contacted Host', substr($istr,45,8)),
        join (';', 'SAP System ID (RFC)', substr($istr,53, 8)),
        join (';', 'SAP System ID (DB)', substr($istr,61, 8)),
        join (';', 'Database Host Name',  substr($istr, 69, 32)),
        join (';', 'Database System Type', substr($istr, 101, 10)),
        join (';', 'SAP Basis Release', substr($istr, 111, 4)),
        join (';', 'SAP Machine ID', substr($istr, 115,5)), 
        join (';', 'Operating System', substr($istr, 120, 10)),
        join (';', 'TZ_Offset (secs)', substr($istr, 130, 6)),
        join (';', 'DST_Flag', substr($istr, 136, 1))
    );
     
     return($ret_val, $info);  
}

# Autoload methods go after =cut, and are processed by the autosplit program.

1;
}
__END__
# Below is the stub of documentation for your module. You better edit it!
# the documentation is in the SAP_RFC.pod file 
