#!rfcperl 
# return the SAP System Information

use SAP_RFC;

$buffer = '';

read (STDIN, $buffer, $ENV{'CONTENT_LENGTH'});

#split the name-value pairs
@pairs = split(/&/, $buffer);

foreach $pair (@pairs)
{
    ($name, $value) = split(/=/, $pair);
    # un-Webify plus signs and %-encoding
    $value =~ tr/+/ /;
    $value =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C",hex($1))/eg;

    $FORM{$name} = $value;
}

# Connect to SAP
$sap_system = $FORM{'sap_sys'};
$sap_client = $FORM{'sap_cli'};
$sap_user = $FORM{'sap_user'};
$sap_pwd = $FORM{'sap_pwd'};
$sap_trc = 'NO';
$ret = 999;

print STDOUT "Content-Type: text/html\n\n";

print STDOUT "<HTML><HEAD>\n";
print STDOUT "<TITLE>SAP System Information</TITLE>\n";
print STDOUT "</HEAD><BODY>\n";
print STDOUT "<H1>SAP System Information</H1>\n";
print STDOUT "<P>\n";

$ret = &SAP_RFC::open($sap_system, $sap_client, 
		      $sap_user, $sap_pwd, $sap_trc);

if ($ret != 0)   # connect failed
{
    print STDOUT "<STRONG>SAP_RFC::open($sap_system, $sap_client,";
    print STDOUT "$sap_user, $sap_pwd, $sap_trc)";
    print STDOUT " Failed !!! </STRONG>\n";
print "<P> buffer = $buffer \n";    
    print STDOUT "</BODY></HTML>\n";
    exit;
}
else   # connect said it was OK
{
    $ping_ret = 999;
    $ping_str = ' ';
    ($ping_ret, $ping_str) = &SAP_RFC::ping();

    if ($ping_ret != 0) # user not logged in
    {
	print STDOUT "<STRONG>SAP_RFC::ping Failed !!!</STRONG>\n";
	print STDOUT "The returned string is: \n $ping_str\n";
	print STDOUT "</BODY></HTML>\n";
	exit;
    }
}

# set up for the RFC Call
$abap = "RFC_SYSTEM_INFO";
$mess_str = '	     ';
$nm_exp = 'RFCSI_EXPORT'; # record name coming FROM SAP
$nm_imp = ' ';         # record name sent TO SAP
$ret_str = ' ';
$ret = 999;

($ret, $ret_str) = &SAP_RFC::callrxx($abap, $mess_str, $nm_exp, $nm_imp);
if ($ret != 0)   # call failed
{
    print STDOUT "<STRONG>SAP_RFC::callrx1($abap, $mess_str, $nm_exp, $nm_imp) ";
    print STDOUT "- FAILED !!!</STRONG> \n";
    print STDOUT "</BODY></HTML>\n";
    $ret = &SAP_RFC::close();
    exit;
}

# print out a header
print STDOUT "<H2>SAP System Information</H2> \n";
# Define Header
print STDOUT "<TABLE BORDER> \n";
print STDOUT "<TR><TH>Parameter</TH><TH>Value</TH></TR>\n";

# now we have a string with name - value pairs 
# that need to be split and printed out.
$tmp = substr($ret_str, 0, 3);
print STDOUT "<TR><TD>RFC Log Version</TD><TD>$tmp</TD></TR>\n";
$tmp = substr($ret_str, 3, 4);
print STDOUT "<TR><TD>Character Set (SAP)</TD><TD>$tmp</TD></TR>\n";
$tmp = substr($ret_str, 7, 3);
print STDOUT "<TR><TD>Integer Format</TD><TD>$tmp</TD></TR>\n";
$tmp = substr($ret_str, 10, 3);
print STDOUT "<TR><TD>Floating Point Format</TD><TD>$tmp</TD></TR>\n";
$tmp = substr($ret_str, 13, 32);
print STDOUT "<TR><TD>Logical SAP Destination</TD><TD>$tmp</TD></TR>\n";
$tmp = substr($ret_str, 45, 8);
print STDOUT "<TR><TD>Contacted Host</TD><TD>$tmp</TD></TR>\n";
$tmp = substr($ret_str, 53, 8);
print STDOUT "<TR><TD>SAP System ID (RFC)</TD><TD>$tmp</TD></TR>\n";
$tmp = substr($ret_str, 61, 8);
print STDOUT "<TR><TD>SAP System ID (DB)</TD><TD>$tmp</TD></TR>\n";
$tmp = substr($ret_str, 69, 32);
print STDOUT "<TR><TD>Database Host Name</TD><TD>$tmp</TD></TR>\n";
$tmp = substr($ret_str, 101, 10);
print STDOUT "<TR><TD>Database System Type</TD><TD>$tmp</TD></TR>\n";
$tmp = substr($ret_str, 111, 4);
print STDOUT "<TR><TD>SAP Basis Release</TD><TD>$tmp</TD></TR>\n";
$tmp = substr($ret_str, 115, 5);
print STDOUT "<TR><TD>SAP Machine ID</TD><TD>$tmp</TD></TR>\n";
$tmp = substr($ret_str, 120, 10);
print STDOUT "<TR><TD>Operating System</TD><TD>$tmp</TD></TR> \n";
$tmp = substr($ret_str, 130, 6);
print STDOUT "<TR><TD>Time Zone Offset (secs)</TD><TD>$tmp</TD></TR>\n";
print STDOUT "</TABLE>\n";
$tmp = substr($ret_str, 136, 1);
if ($tmp eq 'X')
{
    print STDOUT "<STRONG>This system uses \n";
}
else
{
    print STDOUT "<STRONG>This system Does Not use \n";
}
print STDOUT "Daylight Savings Time</STRONG>\n";
print STDOUT"<HR>";
print STDOUT "</BODY> </HTML>\n";

# close SAP connection and exit
$ret = &SAP_RFC::close();

exit;
