/***********************************************************************
 * rfc_callrx.c
 *
 * Part of SAP_RFC Module
 *
 * AUTHOR:
 *      Garth Kennedy (garth@comm.mot.com or garth@mcs.net)
 *      Land Mobile Products  Motorola Inc. 
 *      Schaumburg, Ill.

 * COPYRIGHT NOTICE:
 *      Copyright 1996,1997   Motorola Inc.;
 *      Permission to use, copy modify and distribute without charge
 *      this software, documentation etc. is granted, provided that
 *      this comment and the author's name is retained. Neither the
 *      author or Motorola assume any responsibility for problems
 *     resulting from the use of this software.
 *
 ***********************************************************************/
#include "rfclib.h"

/******************************************************************************
 * rfc_callrx2(called_abap, message_in, message_received_1, message_received_2)
 *
 * Description:	Call the SAP RFC and and pass a message
 *              Receives two (2) parameters from SAP. 
 *              Returns the first received parameter
 *
 * Garth Kennedy   29 April 1996
 ******************************************************************************/
int rfc_callrx2( char * abap, char * mess_in, char * mess1_out, char * mess2_out)
{
   RFC_PARAMETER      exporting[32];
   RFC_PARAMETER      importing[32];
   RFC_TABLE          tables[32];
   static RFC_RC      rfc_rc;
   char 	      *exception_ptr;
   char rfc_cmd[50];
   char  rfc_mess[250];
   char               e_status[300];       /* error and status return */
   char               sjunk[300];          /* return of exported record */
   int                i;
   int error;
   int                ret_val;    /* value to be returned to caller */
       
    for (i = 0; i < 250; i++)
        rfc_mess[i] = ' ';

    ret_val = RFC_ERROR;   /* default to error response */
    
    strcpy(rfc_cmd, abap);   /* copy the RFC name */
    strcpy(rfc_mess, mess_in);  /* copy the message to pass */
         
     
    strncpy(rfc_cmd, abap,48);   /* copy the RFC name */
    strncpy(rfc_mess, mess_in, 248);  /* copy the message to pass */
         
     for (i = 0; i < 250; i++)
     {    /* make sure that the string is space filled */
         if (rfc_mess[i] < 0x20)
             rfc_mess[i] = 0x20;
         e_status[i] = 0x20;
     }
    

       /* argument passed to the remote R/3 ABAP function */
   exporting[0].name = "IMPORT_STRING";
   exporting[0].nlen = 13;
   exporting[0].addr = rfc_mess;
   exporting[0].leng = 250;
   exporting[0].type = TYPC;
   exporting[1].name = NULL;

       /* result that we expect from the remote R.3 ABAP function */
   importing[0].name = "EXPORT_STRING";
   importing[0].nlen = 13;
   importing[0].addr = e_status;
   importing[0].leng = 250;
   importing[0].type = TYPC;
   importing[1].name = "EXPORT_STRING2";
   importing[1].nlen = 14;
   importing[1].addr = sjunk;
   importing[1].leng = 250;
   importing[1].type = TYPC;
   importing[2].name = NULL;

       /* not used */
   tables[0].name    = NULL;

   
    SAP_Timed_Out = RFC_OK;
        
    if (signal(SIGALRM, sap_time_out) != SIG_ERR)
    {
        alarm(RFC_TIMEOUT); /* set alarm */
            
               /* do the call */
        rfc_rc = RfcCallReceive( handle, rfc_cmd, exporting,
                             importing, tables, &exception_ptr);
                             
        alarm(0);  /* Rfc CallReceive did not time out */
            
        if (SAP_Timed_Out == RFC_BAD)
        {
            ret_val = RFC_TO;
        }
        else     /* OK - No timeout */
        {
            if (rfc_rc != RFC_OK)
                ret_val = RFC_ERROR;
            else
                ret_val = RFC_OK;
        }
    }   /* end if Time Out alarm loop */

    strcpy(mess1_out, e_status);
    strcpy(mess2_out, sjunk);
    
    return ret_val;

}    /* end rfc_callrx2()   */



/******************************************************************************
 * rfc_callrx1()
 *
 * Description:	Call the SAP RFC and and pass a message
 *              Receives one (1) parameters from SAP. 
 *
 * Garth Kennedy   29 April 1996
 ******************************************************************************/
int rfc_callrx1( char * abap, char * mess_in, char * mess_out)
{
   RFC_PARAMETER      exporting[32];
   RFC_PARAMETER      importing[32];
   RFC_TABLE          tables[32];
   static RFC_RC      rfc_rc;
   char 	      *exception_ptr;
   char  rfc_cmd[50];
   char   rfc_mess[250];
   char               e_status[300];       /* error and status return */
   int                i;
   int                ret_val;    /* value to be returned to caller */
   int   error;
       

    for (i = 0; i < 250; i++)
        rfc_mess[i] = ' ';

    ret_val = RFC_ERROR;   /* default to error response */
    
    strcpy(rfc_cmd, abap);   /* copy the RFC name */
    strcpy(rfc_mess, mess_in);  /* copy the message to pass */
         
     
     for (i = 0; i < 250; i++)
     {    /* make sure that the string is space filled */
         if (rfc_mess[i] < 0x20)
             rfc_mess[i] = 0x20;
         e_status[i] = 0x20;
     }
    

       /* argument passed to the remote R/3 ABAP function */
   exporting[0].name = "IMPORT_STRING";
   exporting[0].nlen = 13;
   exporting[0].addr = rfc_mess;
   exporting[0].leng = 250;
   exporting[0].type = TYPC;
   exporting[1].name = NULL;

       /* result that we expect from the remote R.3 ABAP function */
   importing[0].name = "EXPORT_STRING";
   importing[0].nlen = 13;
   importing[0].addr = e_status;
   importing[0].leng = 250;
   importing[0].type = TYPC;
   importing[1].name = NULL;

       /* not used */
   tables[0].name    = NULL;

            
    SAP_Timed_Out = RFC_OK;
        
    if (signal(SIGALRM, sap_time_out) != SIG_ERR)
    {
        alarm(RFC_TIMEOUT); /* set alarm */
               /* do the call */
        rfc_rc = RfcCallReceive( handle, rfc_cmd, exporting,
                             importing, tables, &exception_ptr);
                             
        alarm(0);  /* Rfc CallReceive did not time out */
            
        if (SAP_Timed_Out == RFC_BAD)
        {
            ret_val = RFC_TO;
        }
        else     /* OK - No timeout */
        {
            if (rfc_rc != RFC_OK)
                ret_val = RFC_ERROR;
            else
                ret_val = RFC_OK;
        }
    }    /* end if Time Out alarm loop */ 

    strcpy(mess_out, e_status);
    
    return ret_val;

}    /* end rfc_callrx1()   */



/******************************************************************************
 * rfc_callrxx()
 *
 * Description:	Call the SAP RFC and and pass a message
 *              Receives one (1) parameters from SAP. 
 *
 * Garth Kennedy   5 May 1996
 ******************************************************************************/
int rfc_callrxx( char * abap, char * mess_in, char * mess_out, char *nm_exp, char *nm_imp)
{
   RFC_PARAMETER      exporting[32];
   RFC_PARAMETER      importing[32];
   RFC_TABLE          tables[32];
   static RFC_RC      rfc_rc;
   char 	      *exception_ptr;
   char  rfc_cmd[50];
   char   rfc_mess[250];
   char               e_status[300];       /* error and status return */
   int                i;
   int                ret_val;    /* value to be returned to caller */
   int   error;
   char   exp_name[20];
   int    exp_len;
   char   imp_name[20];
   int    imp_len;
       
    /* Check and make sure that there is at least a quasi valid export or */
    /* import structure name */
    exp_len = -999;
    imp_len = -999;
    
    for (i = 0; i < 20; i++)
    {
        if (nm_exp[i] > 0x2F)
            exp_len = i;
            
        if (nm_imp[i] > 0x2F)
            imp_len = i;
    }

    if (exp_len > 3)   /* must have at least four characters in name */
    {
        strcpy(exp_name, nm_exp);
        exp_len = strlen(exp_name);
    }
    if (imp_len > 3)   /* must have at least four characters in name */
    {
        strcpy(imp_name, nm_imp);
        imp_len = strlen(imp_name);
    }
    
    if ((imp_len < 4) && (exp_len < 4))  /* no structure names given */
    {                                     /* Bail Out */
        ret_val = RFC_BAD_IN;  /* bad input */
        return ret_val;
    }
    
    for (i = 0; i < 250; i++)
        rfc_mess[i] = ' ';

    ret_val = RFC_ERROR;   /* default to error response */
    
    strcpy(rfc_cmd, abap);   /* copy the RFC name */
    strcpy(rfc_mess, mess_in);  /* copy the message to pass */
         
     
     for (i = 0; i < 250; i++)
     {    /* make sure that the string is space filled */
         if (rfc_mess[i] < 0x20)
             rfc_mess[i] = 0x20;
         e_status[i] = 0x20;
     }
    
    
    

       /* argument passed to the remote R/3 ABAP function */
    if (imp_len > 3)
    {
        exporting[0].name = imp_name;
        exporting[0].nlen = imp_len;
        exporting[0].addr = rfc_mess;
        exporting[0].leng = 250;
        exporting[0].type = TYPC;
        exporting[1].name = NULL;
    }
    else   /* not using any */
    {
        exporting[0].name = NULL;
    }

       /* result that we expect from the remote R.3 ABAP function */
    if (exp_len > 3)
    {
        importing[0].name = exp_name;
        importing[0].nlen = exp_len;
        importing[0].addr = e_status;
        importing[0].leng = 250;
        importing[0].type = TYPC;
        importing[1].name = NULL;
    }
    else
    {
        importing[0].name = NULL;
    }
       /* not used */
   tables[0].name    = NULL;

            
    SAP_Timed_Out = RFC_OK;
        
    if (signal(SIGALRM, sap_time_out) != SIG_ERR)
    {
        alarm(RFC_TIMEOUT); /* set alarm */
               /* do the call */
        rfc_rc = RfcCallReceive( handle, rfc_cmd, exporting,
                             importing, tables, &exception_ptr);
                             
        alarm(0);  /* Rfc CallReceive did not time out */
            
        if (SAP_Timed_Out == RFC_BAD)
        {
            ret_val = RFC_TO;
        }
        else     /* OK - No timeout */
        {
            if (rfc_rc != RFC_OK)
                ret_val = RFC_ERROR;
            else
                ret_val = RFC_OK;
        }
    }    /* end if Time Out alarm loop */ 

    strcpy(mess_out, e_status);
    
    return ret_val;

}    /* end rfc_callrxx()   */


/*****************************************************/
/**********************************************
 * void sap_time_out()
 *
 * this function us executed when the alarm clock trips.
 * This function sets the SAP_Timed_Out flag.
 *
 * Garth Kennedy     29 April 1996
 *************************************************/
 void sap_time_out()
{
    
    SAP_Timed_Out = RFC_BAD;
}  /* end of timed_out() */





