/***********************************************************************
 * rfc_open.c
 *
 * Part of SAP_RFC perl module - version 0.19  released 1 Aug 1997
 *
 * AUTHOR:
 *      Garth Kennedy (garth@comm.mot.com or garth@mcs.net)
 *      Land Mobile Products  Motorola Inc. 
 *      Schaumburg, Ill.

 * COPYRIGHT NOTICE:
 *      Copyright 1996, 1997   Motorola Inc.;
 *      Permission to use, copy modify and distribute without charge
 *      this software, documentation etc. is granted, provided that
 *      this comment and the author's name is retained. Neither the
 *      author or Motorola assume any responsibility for problems
 *     resulting from the use of this software.
 *
 * DATE:  1 Aug 1997
 *
 ***********************************************************************/
#include "rfclib.h"

/********************************************************************
 * rfc_open(system, client, user, password, trace)
 *
 * Description:	Open/close the connection to the R/3 system 
 *
 * Garth Kennedy  27 April 1996
 ********************************************************************/
int rfc_open(char * system, char * client1, char * user1, 
         char * password, char * trace)
{
   int ret_val;
   int error;
   RFC_OPTIONS        rfc_opt;
   RFC_ENV            new_env;
   char  sys[10];
   char  client[10];
   char  user[50];
   char  passwd[50];
   char  trace_in[10];


    sap_trace = 0;

    strcpy(sys, system);   /* copy the System name */
    strcpy(client, client1);  /* copy the client name */
    strcpy(user, user1);   /* copy the user login name */
    strcpy(passwd, password);  /* copy the user password */
    strcpy(trace_in,  trace);   /* copy the trace parameter */
      
    if ((trace_in[0] == 'Y') || (trace_in[0] == 'y') || (trace_in[0] == 'T') || (trace_in[0] == 't'))
        sap_trace = 1;
    else
        sap_trace = 0;

       /* -----------------------------------------------
        * Install error handler
        * ---------------------------------------------*/
      
  
    new_env.allocate = NULL;
    new_env.errorhandler = sap_rfc_error;
    RfcEnvironment( &new_env );

       /* info necessary for the open, additional info must be supplied
        * in the sideinfo table
        */
    rfc_opt.client   = client;
    rfc_opt.user     = user;
    rfc_opt.language = "E";
    rfc_opt.password = passwd;
    rfc_opt.trace    = sap_trace;
    rfc_opt.mode     = RFC_MODE_R3ONLY;
    rfc_opt.destination = sys;
    rfc_opt.connopt  = 0; /* use the SIDEINFO table  */


    
       /* ------------------------------------------ *
        * open connection                            *
        * ------------------------------------------ */

    handle = RfcOpen( &rfc_opt );

    if ( handle == RFC_HANDLE_NULL )
    {
        return RFC_ERROR;
    } 
    else
    {
        return RFC_OK;
    }
        
}   /* end rfc_open()  */


 
/************************************************************
 * rfc_close()
 *
 * Close the connection to SAP
 *
 * Garth Kennedy  27 April 1996
 ***********************************************************/
int rfc_close( )
{
       
    RfcClose( handle );
        
    return RFC_OK;
            
}     /* end rfc_close()  */


 
/************************************************************
 * rfc_version()
 *
 * Return version info about SAP_RFC
 *
 * Garth Kennedy  1 Aug 1997
 ***********************************************************/
double rfc_version( )
{
    double vers;
    
    vers = 0.19;
    
    return vers;
            
}     /* end rfc_version()  */

