/***********************************************************************
 * rfclib.h
 *
 * Part of SAP_RFC - version 0.19  released 1 Aug 1997
 *
 * AUTHOR:
 *      Garth Kennedy (garth@comm.mot.com or garth@mcs.net)
 *      Land Mobile Products  Motorola Inc. 
 *      Schaumburg, Ill.

 * COPYRIGHT NOTICE:
 *      Copyright 1996, 1997   Motorola Inc.;
 *      Permission to use, copy modify and distribute without charge
 *      this software, documentation etc. is granted, provided that
 *      this comment and the author's name is retained. Neither the
 *      author or Motorola assume any responsibility for problems
 *     resulting from the use of this software.
 *
 * DATE:  1 August 1997
 *
 ***********************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <saprfc.h>
#include <time.h>
#include <unistd.h>
#include <signal.h>

#ifndef SAPRFC_H
#define SAPRFC_H

#ifdef MAIN
RFC_HANDLE              handle;
int sap_trace;
#else
extern RFC_HANDLE       handle;
extern int sap_trace;
#endif
int sap_trace;
RFC_HANDLE       handle;
int SAP_Timed_Out;     /* Flag that indicates SAP timed out */

/* Define return flags */
#define RFC_OK     0
#define RFC_ERR    1
#define RFC_ERROR  1
#define RFC_BAD   -1
#define RFC_TO     9
#define RFC_BAD_IN 11

/* Local Defines */
#define RFC_RETRY  3     /* number of times to retry before giving up */
#define RFC_TIMEOUT  180   /* seconds to wait before deciding SAP is not coming back */


/* library function declares */
int rfc_help(char * str);  /* library functions */ 
int rfc_open(char * system, char * client1, char * user1, 
         char * password, char * trace);
int rfc_close();
double rfc_version();
int rfc_rfcping(char * str);
int rfc_sysinfo( char * str);
int rfc_callrx2( char * abap, char * mess_in, char * mess1_out, char * mess2_out);
int rfc_callrx1( char * abap, char * mess_in, char * mess_out);
int rfc_callrxx( char * abap, char * mess_in, char * mess_out, char * exp, char * imp);



/* internal function declarations */
int sap_check_error(char **exception_ptr, char *e_status, RFC_RC rfc_rc);
static void sap_rfc_error(char * operation);
int sap_err_split (char *err_str);
int sap_clear_err();
int sap_err_print_str(char *err_str);
static void rfc_error (char * operation);
void sap_time_out();

 
/******************************************************************
 * sap_rfc_error
 * Description:	dump status after a failure of a remote 
 *              function call - this is a dummy process
 ******************************************************************/
static void 
sap_rfc_error( char * operation )
{
    time_t  tt;
    struct tm  *ts;
     
    RFC_ERROR_INFO error_info;
 
    memset( &error_info, 0, sizeof( error_info ) );
    RfcLastError( &error_info );

    RfcClose( RFC_HANDLE_NULL );
   
   
   /* exit( 1 ); */
}   /* end of sap_rfc_error()  */

#endif /* SAPRFC_H not defined */
